Index: Lib/distutils/util.py
===================================================================
--- Lib/distutils/util.py.orig
+++ Lib/distutils/util.py
@@ -133,7 +133,16 @@ def get_platform ():
             release = macver
             osname = "macosx"
 
-            if (macrelease + '.') >= '10.4.' and \
+            if macrelease:
+                try:
+                    macrelease = tuple(int(i) for i in macrelease.split('.')[0:2])
+                except ValueError:
+                    macrelease = (10, 0)
+            else:
+                # assume no universal support
+                macrelease = (10, 0)
+
+            if (macrelease >= (10, 4)) and \
                     '-arch' in get_config_vars().get('CFLAGS', '').strip():
                 # The universal build will build fat binaries, but not on
                 # systems before 10.4
Index: Mac/BuildScript/build-installer.py
===================================================================
--- Mac/BuildScript/build-installer.py.orig
+++ Mac/BuildScript/build-installer.py
@@ -108,14 +108,19 @@ SRCDIR = os.path.dirname(
 # $MACOSX_DEPLOYMENT_TARGET -> minimum OS X level
 DEPTARGET = '10.3'
 
-target_cc_map = {
+def getDeptargetTuple():
+    return tuple([int(n) for n in DEPTARGET.split('.')[0:2]])
+
+def getTargetCompiler():
+    target_cc_map = {
         '10.3': 'gcc-4.0',
         '10.4': 'gcc-4.0',
         '10.5': 'gcc-4.0',
         '10.6': 'gcc-4.2',
-}
+    }
+    return target_cc_map.get(DEPTARGET, 'clang')
 
-CC = target_cc_map[DEPTARGET]
+CC = getTargetCompiler()
 
 PYTHON_3 = getVersionTuple() >= (3, 0)
 
@@ -141,7 +146,7 @@ USAGE = textwrap.dedent("""\
 def library_recipes():
     result = []
 
-    if DEPTARGET < '10.5':
+    if getDeptargetTuple() < (10, 5):
         result.extend([
           dict(
               name="Bzip2 1.0.5",
@@ -318,7 +323,7 @@ def pkg_recipes():
         ),
     ]
 
-    if DEPTARGET < '10.4':
+    if getDeptargetTuple() < (10, 4):
         result.append(
             dict(
                 name="PythonSystemFixes",
@@ -509,7 +514,7 @@ def parseOptions(args=None):
     SDKPATH=os.path.abspath(SDKPATH)
     DEPSRC=os.path.abspath(DEPSRC)
 
-    CC=target_cc_map[DEPTARGET]
+    CC=getTargetCompiler()
 
     print "Settings:"
     print " * Source directory:", SRCDIR
